@@ -17,14 +17,11 @@ $Data::Dumper::Sortkeys  = 1;
 my $version = '1.2.1';   # which EOP version to be created
 
 @ARGV==1
-   or die "ERROR: one filename required";
+   or die "ERROR: one filename required\n";
 
 my ($filename) = @ARGV;
 
-my ($type, $eop) = Geo::EOP->from
-  ( $filename
-  , opts_readers => [ sloppy_floats => 1 ]
-  );
+my ($type, $eop) = Geo::EOP->from($filename, sloppy_floats => 1);
 
 print "EOP type   = $type\n";
 my ($thema, $obs) = unpack_type $type;
