@@ -1,13 +1,13 @@
-# Copyrights 2008-2009 by Mark Overmeer.
+# Copyrights 2008-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 package Geo::EOP;
 use vars '$VERSION';
-$VERSION = '0.13';
+$VERSION = '0.50';
 
 use base 'Geo::GML';
 
@@ -108,7 +108,7 @@ sub init($)
 
     $self->SUPER::init($args);
 
-    $self->prefixes($info->{prefixes});
+    $self->addPrefixes($info->{prefixes});
 
     (my $xsd = __FILE__) =~ s!\.pm!/xsd!;
     my @xsds    = map {glob "$xsd/$_"}
@@ -148,7 +148,7 @@ sub declare(@)
 
 
 sub from($@)
-{   my ($class, $data, %args) = @_;
+{   my ($thing, $data, %args) = @_;
     my $xml = XML::Compile->dataToXML($data);
 
     my $product = type_of_node $xml;
@@ -156,12 +156,19 @@ sub from($@)
     defined $version
         or error __x"no version attribute in root element";
 
-    exists $info{$version}
-        or error __x"EOP version {version} not (yet) supported.  Upgrade Geo::EOP or inform author"
-             , version => $version;
+    my $self;
+    if(ref $thing)   # instance method
+    {   $self = $thing;
+    }
+    else             # class method
+    {   exists $info{$version}
+            or error __x"EOP version {version} not (yet) supported.  Upgrade Geo::EOP or inform author"
+                , version => $version;
 
-    my $self    = $class->new(eop_version => $version, %args);
-    my $r       = $self->reader($product);
+        $self    = $thing->new(eop_version => $version);
+    }
+
+    my $r       = $self->reader($product, %args);
     defined $r
         or error __x"do not understand root node {type}", type => $product;
 
